@@ -26,6 +26,10 @@ sub static_ttf :get(static) :view(static) :path(static/(.*\.ttf)) :captured(1) :
 
 sub static_woff :get(static) :view(static) :path(static/(.*\.woff2*)) :captured(1) :content_type(application/font-woff) { }
 
+sub static_mov :get(static) :view(static) :path(static/(.*\.mov*)) :captured(1) :content_type(video/mp4) { }
+
+sub static_mp4 :get(static) :view(static) :path(static/(.*\.mp4*)) :captured(1) :content_type(video/mp4) { }
+
 1;
 
 __END__;
@@ -38,7 +42,7 @@ Terse::Controller::Static - Serve static resources controller
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =cut
 
